
package com.banesco.commons.soap.client.apidebitcardoutappsvc;

import jakarta.xml.bind.JAXBElement;
import jakarta.xml.bind.annotation.XmlElementDecl;
import jakarta.xml.bind.annotation.XmlRegistry;

import javax.xml.namespace.QName;

/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the com.banesco.commons.soap.client.apidebitcardoutappsvc package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {

    private final static QName _BlockUnblockDebitCardRq_QNAME = new QName("http://xmlns.banesco.com/ApplicationService/APIDebitCardOutAppSvc", "blockUnblockDebitCard_Rq");
    private final static QName _BlockUnblockDebitCardRs_QNAME = new QName("http://xmlns.banesco.com/ApplicationService/APIDebitCardOutAppSvc", "blockUnblockDebitCard_Rs");

    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: com.banesco.commons.soap.client.apidebitcardoutappsvc
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link BlockUnblockDebitCardRq }
     * 
     */
    public BlockUnblockDebitCardRq createBlockUnblockDebitCardRq() {
        return new BlockUnblockDebitCardRq();
    }

    /**
     * Create an instance of {@link BlockUnblockDebitCardRq.Card }
     * 
     */
    public BlockUnblockDebitCardRq.Card createBlockUnblockDebitCardRqCard() {
        return new BlockUnblockDebitCardRq.Card();
    }

    /**
     * Create an instance of {@link BlockUnblockDebitCardRq.Card.CardInfo }
     * 
     */
    public BlockUnblockDebitCardRq.Card.CardInfo createBlockUnblockDebitCardRqCardCardInfo() {
        return new BlockUnblockDebitCardRq.Card.CardInfo();
    }

    /**
     * Create an instance of {@link BlockUnblockDebitCardRq.Card.CardInfo.Customer }
     * 
     */
    public BlockUnblockDebitCardRq.Card.CardInfo.Customer createBlockUnblockDebitCardRqCardCardInfoCustomer() {
        return new BlockUnblockDebitCardRq.Card.CardInfo.Customer();
    }

    /**
     * Create an instance of {@link BlockUnblockDebitCardRq.Card.CardInfo.Customer.PersonInfo }
     * 
     */
    public BlockUnblockDebitCardRq.Card.CardInfo.Customer.PersonInfo createBlockUnblockDebitCardRqCardCardInfoCustomerPersonInfo() {
        return new BlockUnblockDebitCardRq.Card.CardInfo.Customer.PersonInfo();
    }

    /**
     * Create an instance of {@link MsgRqHdr }
     * 
     */
    public MsgRqHdr createMsgRqHdr() {
        return new MsgRqHdr();
    }

    /**
     * Create an instance of {@link BlockUnblockDebitCardRs }
     * 
     */
    public BlockUnblockDebitCardRs createBlockUnblockDebitCardRs() {
        return new BlockUnblockDebitCardRs();
    }

    /**
     * Create an instance of {@link MsgRsHdr }
     * 
     */
    public MsgRsHdr createMsgRsHdr() {
        return new MsgRsHdr();
    }

    /**
     * Create an instance of {@link Status }
     * 
     */
    public Status createStatus() {
        return new Status();
    }

    /**
     * Create an instance of {@link NetworkTrnInfo }
     * 
     */
    public NetworkTrnInfo createNetworkTrnInfo() {
        return new NetworkTrnInfo();
    }

    /**
     * Create an instance of {@link ApplicantData }
     * 
     */
    public ApplicantData createApplicantData() {
        return new ApplicantData();
    }

    /**
     * Create an instance of {@link RecCtrlIn }
     * 
     */
    public RecCtrlIn createRecCtrlIn() {
        return new RecCtrlIn();
    }

    /**
     * Create an instance of {@link VBProtocol }
     * 
     */
    public VBProtocol createVBProtocol() {
        return new VBProtocol();
    }

    /**
     * Create an instance of {@link AdditionalStatus }
     * 
     */
    public AdditionalStatus createAdditionalStatus() {
        return new AdditionalStatus();
    }

    /**
     * Create an instance of {@link BlockUnblockDebitCardRq.Card.CardStatus }
     * 
     */
    public BlockUnblockDebitCardRq.Card.CardStatus createBlockUnblockDebitCardRqCardCardStatus() {
        return new BlockUnblockDebitCardRq.Card.CardStatus();
    }

    /**
     * Create an instance of {@link BlockUnblockDebitCardRq.Card.CardInfo.Customer.PersonInfo.GovIssueIdent }
     * 
     */
    public BlockUnblockDebitCardRq.Card.CardInfo.Customer.PersonInfo.GovIssueIdent createBlockUnblockDebitCardRqCardCardInfoCustomerPersonInfoGovIssueIdent() {
        return new BlockUnblockDebitCardRq.Card.CardInfo.Customer.PersonInfo.GovIssueIdent();
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link BlockUnblockDebitCardRq }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link BlockUnblockDebitCardRq }{@code >}
     */
    @XmlElementDecl(namespace = "http://xmlns.banesco.com/ApplicationService/APIDebitCardOutAppSvc", name = "blockUnblockDebitCard_Rq")
    public JAXBElement<BlockUnblockDebitCardRq> createBlockUnblockDebitCardRq(BlockUnblockDebitCardRq value) {
        return new JAXBElement<BlockUnblockDebitCardRq>(_BlockUnblockDebitCardRq_QNAME, BlockUnblockDebitCardRq.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link BlockUnblockDebitCardRs }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link BlockUnblockDebitCardRs }{@code >}
     */
    @XmlElementDecl(namespace = "http://xmlns.banesco.com/ApplicationService/APIDebitCardOutAppSvc", name = "blockUnblockDebitCard_Rs")
    public JAXBElement<BlockUnblockDebitCardRs> createBlockUnblockDebitCardRs(BlockUnblockDebitCardRs value) {
        return new JAXBElement<BlockUnblockDebitCardRs>(_BlockUnblockDebitCardRs_QNAME, BlockUnblockDebitCardRs.class, null, value);
    }
}
